---
hide:
  - navigation
---

# Version history

Version history is tracked via [Github releases](https://github.com/joeweiss/birdnetlib/releases) and on [PyPi](https://pypi.org/project/birdnetlib/).
